package com.mcwl.communityCenter.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.constant.HttpStatus;
import com.mcwl.common.core.domain.R;
import com.mcwl.common.core.domain.entity.SysUser;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.exception.ServiceException;
import com.mcwl.common.utils.DictUtils;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.communityCenter.constant.AdviceConstant;
import com.mcwl.communityCenter.domain.*;
import com.mcwl.communityCenter.domain.dto.*;
import com.mcwl.communityCenter.domain.vo.CommentVo;
import com.mcwl.communityCenter.domain.vo.PersonHomeVo;
import com.mcwl.communityCenter.domain.vo.PublishReportVo;
import com.mcwl.communityCenter.domain.vo.PublishVo;
import com.mcwl.communityCenter.mapper.*;
import com.mcwl.communityCenter.service.*;
import com.mcwl.system.init.DictInit;
import com.mcwl.system.service.ISysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@Service
@RequiredArgsConstructor
public class PublishReportServiceImpl extends ServiceImpl<PublishReportMapper, PublishReport> implements PublishReportService {

    private final ISysUserService sysUserService;

    private final PublishMapper publishMapper;

    @Override
    public void saveReport(PublishReport publishReport) {

        baseMapper.insertReport(publishReport);

    }

    @Override
    public TableDataInfo getReportList(PageDomain pageDomain) {
        Page<PublishReport> page = new Page<>(pageDomain.getPageNum(), pageDomain.getPageSize());
        baseMapper.selectPage(page, new LambdaQueryWrapper<PublishReport>()
                .orderByAsc(PublishReport::getStatus)
                .orderByDesc(PublishReport::getCreateTime));

        List<PublishReport> publishReportList = page.getRecords();
        List<PublishReportVo> publishReportVoList = new ArrayList<>();

        for (PublishReport publishReport : publishReportList) {
            PublishReportVo publishReportVo = BeanUtil.copyProperties(publishReport, PublishReportVo.class);
            publishReportVo.setUserName(sysUserService.selectUserById(publishReport.getUserId()).getUserName());

            publishReportVo.setReportType(DictInit.getDictValue("community_report", publishReport.getReportType().toString()));



            Publish publish = publishMapper.selectByIdAndTenantIdAndCommunityId(publishReport.getPublishId(), publishReport.getTenantId(), publishReport.getCommunityId());

            if (Objects.nonNull(publish)) {
                publishReportVo.setContent(publish.getContent());
                publishReportVo.setImgUrl(publish.getImageUrl());
                publishReportVo.setFileUrl(publish.getFileUrl());
            }

            publishReportVoList.add(publishReportVo);
        }


        TableDataInfo tableDataInfo = new TableDataInfo();
        tableDataInfo.setRows(publishReportVoList);
        tableDataInfo.setTotal(page.getTotal());
        tableDataInfo.setCode(HttpStatus.SUCCESS);
        tableDataInfo.setMsg("查询成功");
        return tableDataInfo;
    }

    @Override
    public void updateStatus(EditPublishReportStatusRes editPublishReportStatusRes) {
        baseMapper.updateStatus(editPublishReportStatusRes);
        Long tenantId = editPublishReportStatusRes.getTenantId();
        Long communityId = editPublishReportStatusRes.getCommunityId();
        Long publishId = editPublishReportStatusRes.getPublishId();
        if (editPublishReportStatusRes.getStatus() == 2) {
            PublishRemoveRes publishRemoveRes = new PublishRemoveRes();
            publishRemoveRes.setTenantId(tenantId);
            publishRemoveRes.setCommunityId(communityId);
            publishRemoveRes.setPublishId(publishId);
            publishMapper.removePublish(publishRemoveRes);
        }
    }

    @Override
    public void removeReportById(Long id) {
        baseMapper.deleteReportById(id);
    }
}
